pub struct OnInstanceSetupResult {
pub main_class_override: Option<String>,
pub jar_path_override: Option<String>,
pub classpath_extension: Vec<String>,
pub game_modification_version: Option<String>,
}Expand description
Result from the OnInstanceSetup hook
Fields
main_class_override: Option<String>Optional override for the main class
jar_path_override: Option<String>Optional override for the path to the game JAR file
classpath_extension: Vec<String>Optional extension to the classpath, as a list of paths
game_modification_version: Option<String>Optional new version for the game modification